@@ -1,8 +1,10 @@
+use maplit::{btreemap, convert_args};
+
 use super::*;
 
 impl KubeadmControlPlane {
     pub fn aws(name: &str) -> Self {
-        let extra_args = BTreeMap::from([("cloud-provider".to_string(), "aws".to_string())]);
+        let extra_args = convert_args!(btreemap!("cloud-provider" => "aws"));
         let spec = KubeadmControlPlaneSpec {
             kubeadm_config_spec: cabpkv1::KubeadmConfigSpec {
                 cluster_configuration: Some(cabpkv1::ClusterConfiguration {
@@ -43,7 +45,10 @@ impl KubeadmControlPlane {
     }
 
     #[must_use]
-    pub fn set_machine_template(self, machine_template: &MachineTemplate) -> Self {
+    pub fn machine_template<T>(self, machine_template: &T) -> Self
+    where
+        T: MachineTemplate,
+    {
         let infrastructure_ref = machine_template.object_ref();
         let mut kubeadm_control_plane_machine_template = self.spec.machine_template;
         kubeadm_control_plane_machine_template.infrastructure_ref = infrastructure_ref;
@@ -57,7 +62,7 @@ impl KubeadmControlPlane {
     }
 
     #[must_use]
-    pub fn set_replicas(self, replicas: i32) -> Self {
+    pub fn replicas(self, replicas: i32) -> Self {
         let mut kubeadm_control_plane_spec = self.spec;
         kubeadm_control_plane_spec.replicas = Some(replicas);
         Self {
@@ -67,7 +72,7 @@ impl KubeadmControlPlane {
     }
 
     #[must_use]
-    pub fn set_version(self, version: &str) -> Self {
+    pub fn version(self, version: &str) -> Self {
         Self {
             spec: KubeadmControlPlaneSpec {
                 version: version.to_string(),
