@@ -2,11 +2,9 @@ use kube::Resource;
 
 use super::*;
 
-impl ControlPlaneConfigTemplate {
-    pub fn object_ref(&self) -> corev1::ObjectReference {
-        match self {
-            ControlPlaneConfigTemplate::Kubeadm(kubeadm) => kubeadm.object_ref(&()),
-        }
+impl ControlPlaneConfigTemplate for KubeadmConfigTemplate {
+    fn object_ref(&self) -> corev1::ObjectReference {
+        kube::Resource::object_ref(self, &())
     }
 }
 
@@ -26,10 +24,8 @@ impl Infrastructure {
     }
 }
 
-impl MachineTemplate {
-    pub fn object_ref(&self) -> corev1::ObjectReference {
-        match self {
-            MachineTemplate::Aws(aws) => aws.object_ref(&()),
-        }
+impl MachineTemplate for AWSMachineTemplate {
+    fn object_ref(&self) -> corev1::ObjectReference {
+        kube::Resource::object_ref(self, &())
     }
 }
